Scrapinghub command line client
===============================

.. image:: https://img.shields.io/pypi/v/shub.svg
   :target: https://pypi.python.org/pypi/shub
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/shub.svg
   :target: https://pypi.python.org/pypi/shub
   :alt: Python Versions

.. image:: https://github.com/scrapinghub/shub/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/scrapinghub/shub/actions/workflows/tests.yml
   :alt: Tests

.. image:: https://img.shields.io/codecov/c/github/scrapinghub/shub/master.svg
   :target: https://codecov.io/github/scrapinghub/shub?branch=master
   :alt: Coverage report

``shub`` is the Scrapinghub command line client. It allows you to deploy
projects or dependencies, schedule spiders, and retrieve scraped data or logs
without leaving the command line.


Requirements
------------

* Python >= 3.6


Installation
------------

If you have ``pip`` installed on your system, you can install ``shub`` from
the Python Package Index::

    pip install shub

Please note:

* if you are using Python < 3.6, you should pin `shub` to `2.13.0` or lower.
* if you are using Python < 3.9, you should pin `shub` to `2.15.4` or lower.

We also supply stand-alone binaries. You can find them in our `latest GitHub
release`_.

.. _`latest Github release`: https://github.com/scrapinghub/shub/releases/latest


Documentation
-------------

Documentation is available online via Read the Docs:
https://shub.readthedocs.io/, or in the ``docs`` directory.
